backo (Back Office Low Code) documentation — backo 0.0.1 documentation

# backo (Back Office Low Code) documentation

Table of Contents

- Back Office Low Code (backo)
  - What is backo
  - Installation
  - Quickstart
  - Syntax
  - Authentication
  - Routes
  - Actions routes
  - Meta routes
  - Internal usage
  - Workflow and events
  - Transactions
  - CurrentUser
  - Logs
  - Tests & co
- References
  - `Action`
  - `Backoffice`
  - `Collection`
  - `CurrentUser`
  - `Item`
  - Ref & RefsList
  - DBconnector
- Errors
  - `Error`

# Indices and tables

- Index

- Module Index

- Search Page